@@ -5,13 +5,14 @@ class Venue(models.Model):
     """A backstage Venue is a specific local install of backstage."""
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
+
     def __init__(self, venue_path, venue_name):
         self.venue_root = os.path.abspath(os.path.join(venue_path, venue_name))
         self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (venue_name))
-        self.acts_dir = os.path.join(self.venue_root,'acts')
+        self.acts_dir = os.path.join(self.venue_root, 'acts')
 
         if not os.path.exists(venue_root):
-            print 'venue does not exist at %s' % (venue_root)
+            print 'venue does not exist at %s' % self.venue_root
             raise
 
     def get_settings(self):
